local _, private = ...

local Achievement = {
	icons = {}
}

hooksecurefunc("ToggleAchievementFrame", function()
	if Achievement.IconSetup then
		Achievement:IconSetup()
	end
end)

function Achievement:ScheduleUpdate()
	private:ScheduleTimer(function()
		Achievement.UpdateIcons()
	end, 0.0001)
end

function Achievement:UpdateIcons()
	for _, button in pairs(Achievement.icons) do
		local achieve = button:GetParent()
		local achieveID = achieve.id
		if achieveID and private.registeredGuides[achieveID] and achieve:IsVisible() then
			button:Show()
		else
			private:debug("Hiding achievement icon for:" .. (achieveID or 'Unknown'))
			button:Hide()
		end
	end
end

function Achievement:Icon_OnClick(button)
	private:LoadGuide(self:GetParent().id)
end

function Achievement:Icon_OnEnter()
	GameTooltip:ClearAllPoints()
	GameTooltip:ClearLines()
	GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
	GameTooltip:AddLine("Load guide for: " .. self:GetParent().label:GetText())
	GameTooltip:Show()
end

function Achievement:Icon_OnLeave()
	GameTooltip:Hide()
end

function Achievement:IconSetup()
	if AchievementFrame then
		local LibDraggable = LibStub("LibDraggable-1.0")
		LibDraggable:EnableDragging(AchievementFrame, AchievementFrameHeader, AchievementFrameCategoriesContainer, AchievementFrameAchievementsContainer, AchievementFrameStatsContainer)
		LibDraggable:EnableSavePosition(AchievementFrame, AchievementHunterDB.achievementFrameStore)
	end
	for achID = 1, 100 do
		local button = _G["AchievementFrameAchievementsContainerButton" .. achID]
		if not button then
			private:debug("Uh oh, Achievement Hunter button failed for " .. achID)
			break
		end
		local iconFrame = CreateFrame("Button", "", button, "OptionsButtonTemplate")
		iconFrame:SetSize(20, 20)
		iconFrame:SetPoint("TOPRIGHT", button, "TOPRIGHT", -5, -5)
		iconFrame:SetFrameLevel(button.shield:GetFrameLevel() + 1)
		iconFrame:SetScript("OnEnter", self.Icon_OnEnter)
		iconFrame:SetScript("OnLeave", self.Icon_OnLeave)
		iconFrame:HookScript("OnClick", self.Icon_OnClick)
		iconFrame.texture = iconFrame:CreateTexture("", "OVERLAY")
		iconFrame.texture:SetAllPoints(true)
		iconFrame.texture:SetTexture("Interface\\ICONS\\Achievement_Quests_Completed_07")
		button.achievementButton = iconFrame
		self.icons[achID] = iconFrame
	end
	local achievescroll=_G['AchievementFrameAchievementsContainer']
	hooksecurefunc("HybridScrollFrame_Update", function(scrollframe)
		if scrollframe == achievescroll then
			self.ScheduleUpdate()
		end
	end)
	achievescroll:HookScript("OnVerticalScroll", self.ScheduleUpdate)
	achievescroll:HookScript("OnMouseWheel", self.ScheduleUpdate)
	achievescroll.scrollDown:HookScript("OnClick", self.ScheduleUpdate)
	achievescroll.scrollUp:HookScript("OnClick", self.ScheduleUpdate)
	self.IconSetup = nil
end