local AchievementHunter, private = ...

private = LibStub("AceAddon-3.0"):NewAddon(private, AchievementHunter, "AceTimer-3.0", "AceEvent-3.0", "AceBucket-3.0")
private.HereBeDragons = LibStub("HereBeDragons-1.0")

private.registeredGuides = {}

function private:RegisterGuide(data)
	private.registeredGuides[data.achieveID] = private.Guide:New(data)
end

local L = private.L or {}
L["MinimapLeftClick"] = "Click to toggle Achievement Hunter"
L["NoGuideText"] = "No achievement selected.\nOpen Achievements to select guide."
L["GuideCompleteText"] = "Achievement complete.\nOpen Achievements to select new guide."

local frame = CreateFrame("Frame", nil, UIParent)
frame:SetFrameStrata("MEDIUM")
frame:SetSize(320, 100)
frame:SetPoint("CENTER", 0, 0)
frame:SetResizable(true)
frame:SetToplevel(true)
frame:SetScript("OnDragStart", frame.StartMoving)
frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
frame:SetBackdrop({
	bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	tile = true,
	tileSize = 16,
	edgeSize = 16,
	insets = {left = 4, right = 4, top = 4, bottom = 4}
})
frame:SetBackdropBorderColor(0.2, 0.2, 0.2, 1)
local frameTitle = frame:CreateFontString("Frame_Title", "OVERLAY", "GameFontNormalLarge")
frameTitle:SetPoint("TOP", 0, -7)
frameTitle:SetText("ACHIEVEMENT HUNTER")
frameTitle:SetFont("Fonts\\skurri.ttf", 20, "THICKOUTLINE")
local frameText = frame:CreateFontString("Frame_Title", "OVERLAY", "GameFontNormal")
frameText:SetPoint("TOPLEFT", 10, -30)
frameText:SetText(L["NoGuideText"])
frameText:SetJustifyH("LEFT")
local LibDraggable = LibStub("LibDraggable-1.0")

function private:SetGuideText(text)
	frameText:SetText(text)
end

private.trackAchievement = {}

function private:LoadGuide(achieveID)
	local guide = private.registeredGuides[achieveID]
	if guide then
		private:debug("Loading guide: " .. achieveID)
		private.trackAchievement.guide = guide
		self:ChangeNextStep()
		AchievementHunterDB.loadedGuide = achieveID
		return
	end
	local isOurs = select(4, GetAchievementInfo(achieveID))
	if isOurs then
		AchievementHunterDB.loadedGuide = nil
		private:SetGuideText(L["NoGuideText"])
		private:debug("We've completed our tracked achievement.")
		return
	end
	print("Uh oh, attemped to load guide, but we don't have a guide for " .. achieveID)
end

function private:ChangeNextStep()
	local guide = private.trackAchievement.guide
	private.trackAchievement = {}
	local achieveSubID = guide:exec()
	if achieveSubID and achieveSubID ~= -1 then
		private.trackAchievement.guide = guide
		private.trackAchievement.achieveSubID = achieveSubID
	else
		AchievementHunterDB.loadedGuide = nil
		private:SetGuideText(L["GuideCompleteText"])
	end
end

function private:CriteriaUpdate(achieveID)
	if not private.trackAchievement.guide then
		return
	end
	local trackAchieveID, trackAchieveSubID = private.trackAchievement.guide.achieveID, private.trackAchievement.achieveSubID
	if trackAchieveID then
		if trackAchieveSubID then
			local isOurs = select(3, GetAchievementCriteriaInfo(trackAchieveID, trackAchieveSubID))
			if isOurs then
				private:ChangeNextStep()
				private:debug("We've completed our tracked achievement & sub-achievement.")
			end
		else
			local isOurs = select(4, GetAchievementInfo(trackAchieveID))
			if isOurs then
				private:ChangeNextStep()
				private:debug("We've completed our tracked achievement.")
			end
		end
		return
	end
	private:debug("CriteriaUpdate called, but our tracked acheivement isn't complete")
end
private:RegisterBucketEvent("CRITERIA_UPDATE", 1, private.CriteriaUpdate)

function private:OnEnable()
	private:ScheduleTimer(function()
		if AchievementHunterDB.loadedGuide then
			private:LoadGuide(AchievementHunterDB.loadedGuide)
		end
	end, 0.0001)
end

function private:OnInitialize()
	local defaults = {
		show = true,
		debug = false,
		frameStore = {},
		achievementFrameStore = {},
		minimapPos = 220
	}
	AchievementHunterDB = AchievementHunterDB or defaults
	if AchievementHunterDB.show then
		frame:Show()
	else
		frame:Hide()
	end
	private.DEBUG = AchievementHunterDB.debug
	LibDraggable:EnableDragging(frame)
	LibDraggable:SetClampedToScreen(frame, true)
	LibDraggable:EnableSavePosition(frame, AchievementHunterDB.frameStore)
	local dataObj = LibStub("LibDataBroker-1.1"):NewDataObject(AchievementHunter, {
		type = "launcher",
		icon = "Interface\\ICONS\\Achievement_Quests_Completed_07",
		OnClick = function(_, button)
			if button == "LeftButton" then
				local isVisible = frame:IsVisible()
				AchievementHunterDB.show = not isVisible
				if isVisible then
					frame:Hide()
				else
					frame:Show()
				end
			else
				print("Debug " .. (private.DEBUG and "disabled" or "enabled"))
				private.DEBUG = not private.DEBUG
				AchievementHunterDB.debug = private.DEBUG
			end
		end,
		OnTooltipShow = function(tooltip)
			tooltip:AddLine(AchievementHunter)
			tooltip:AddLine(L["MinimapLeftClick"])
		end,
	})
	local LDBIcon = LibStub("LibDBIcon-1.0")
	LDBIcon:Register(AchievementHunter, dataObj, AchievementHunterDB)
	LDBIcon:Show(AchievementHunter)
end