local _, private = ...

local type, pairs = type, pairs

function private:dump(o)
	if type(o) == 'table' then
		local s = '{ '
		for k, v in pairs(o) do
			if type(k) ~= 'number' then k = '"'..k..'"' end
			s = s .. '['..k..'] = ' .. private:dump(v) .. ','
		end
		return s .. '} '
	else
		return tostring(o)
	end
end

private.DEBUG = false

function private:debug(msg)
	if private.DEBUG then
		print("AchievementHunter Debug:: " .. msg)
	end
end

local lastWaypoint

function private:AddWaypoint(zone, x, y, title)
	if TomTom then
		if lastWaypoint then
			TomTom:RemoveWaypoint(lastWaypoint)
		end
		lastWaypoint = TomTom:AddMFWaypoint(zone, nil, x / 100, y / 100, {
			title = title,
			persistent = false,
			arrivaldistance = 10,
			cleardistance = 0
		})
	end
end

function private:RemoveWaypoint()
	if lastWaypoint then
		TomTom:RemoveWaypoint(lastWaypoint)
		lastWaypoint = nil
	end
end

function private:HideWaypoint()
	if lastWaypoint then
		TomTom:HideWaypoint(lastWaypoint)
	end
end

function private:ShowWaypoint()
	if lastwaypoint then
		TomTom:ShowWaypoint(lastWaypoint)
	end
end

function private:GetDistance(zoneID, destX, destY)
	local currentX, currentY, currentMapID, currentLevel = private.HereBeDragons:GetPlayerZonePosition()
	if currentMapID == zoneID then
		return private.HereBeDragons:GetWorldDistance(zoneID, currentX, currentY, destX / 100, destY / 100)
	else
		return private.HereBeDragons:GetZoneDistance(currentMapID, currentLevel, currentX, currentY, zoneID, nil, destX / 100, destY / 100)
	end
end