local _, private = ...
if not private then return end

local Continent, Zone = private.Continent, private.Zone

local exploreAchievements = {
	-- Kalimdor
	--[Continent.Kalimdor] = 43,
	[Zone.Durotar] = 728,
	[Zone.Mulgore] = 736,
	[Zone.NorthernBarrens] = 750,
	[Zone.Teldrassil] = 842,
	[Zone.Darkshore] = 844,
	[Zone.Ashenvale] = 845,
	[Zone.ThousandNeedles] = 846,
	[Zone.StonetalonMountains] = 847,
	[Zone.Desolace] = 848,
	[Zone.Feralas] = 849,
	[Zone.DustwallowMarsh] = 850,
	[Zone.Tanaris] = 851,
	[Zone.Azshara] = 852,
	[Zone.Felwood] = 853,
	[Zone.UnGoroCrater] = 854,
	[Zone.Moonglade] = 855,
	[Zone.Silithus] = 856,
	[Zone.Winterspring] = 857,
	[Zone.AzuremystIsle] = 860,
	[Zone.BloodmystIsle] = 861,
	[Zone.SouthernBarrens] = 4996,
	-- Eastern Kingdoms
	--[Continent.EasternKingdoms] = 42,
	[Zone.DunMorogh] = 627,
	[Zone.ArathiHighlands] = 761,
	[Zone.Badlands] = 765,
	[Zone.BlastedLands] = 766,
	[Zone.TrisfalGlades] = 768,
	[Zone.SilverpineForest] = 769,
	[Zone.WesternPlaguelands] = 770,
	[Zone.EasternPlaguelands] = 771,
	[Zone.HillsbradFoothills] = 772,
	[Zone.Hinterlands] = 773,
	[Zone.SearingGorge] = 774,
	[Zone.BurningSteppes] = 775,
	[Zone.ElwynnForest] = 776,
	[Zone.DeadwindPass] = 777,
	[Zone.Duskwood] = 778,
	[Zone.LochModan] = 779,
	[Zone.RedridgeMountains] = 780,
	[Zone.NorthernStranglethorn] = 781,
	[Zone.SwampOfSorrows] = 782,
	[Zone.Westfall] = 802,
	[Zone.Wetlands] = 841,
	[Zone.Ghostlands] = 858,
	[Zone.EversongWoods] = 859,
	[Zone.IsleOfQuelDanas] = 868,
	[Zone.CapeOfStranglethorn] = 4995,
	-- Outland
	--[Continent.Outland] = 44,
	[Zone.Netherstorm] = 843,
	[Zone.HellfirePeninsula] = 862,
	[Zone.Zangarmarsh] = 863,
	[Zone.ShadowmoonValleyOutland] = 864,
	[Zone.BladesEdgeMountains] = 865,
	[Zone.NagrandOutland] = 866,
	[Zone.TerokkarForest] = 867,
	-- Northrend
	--[Continent.Northrend] = 45,
	[Zone.CrystalsongForest] = 1457,
	[Zone.HowlingFjord] = 1263,
	[Zone.BoreanTundra] = 1264,
	[Zone.Dragonblight] = 1265,
	[Zone.GrizzlyHills] = 1266,
	[Zone.ZulDrak] = 1267,
	[Zone.SholazarBasin] = 1268,
	[Zone.StormPeaks] = 1269,
	[Zone.Icecrown] = 1270,
	-- Cataclysm
	--[Continent.Cataclysm] = 4868,
	[Zone.Vashjir] = 4825,
	[Zone.MountHyjal] = 4863,
	[Zone.Deepholm] = 4864,
	[Zone.Uldum] = 4865,
	[Zone.TwilightHighlands] = 4866,
	-- Pandaria
	--[Continent.Pandaria] = 8974,
	[Zone.JadedForest] = 6351,
	[Zone.ValleyOfTheFourWinds] = 6969,
	[Zone.KrasarangWilds] = 6975,
	[Zone.KunLaiSummit] = 6976,
	[Zone.TownlongSteppes] = 6977,
	[Zone.DreadWastes] = 6978,
	[Zone.ValeOfEternalBlossoms] = 6979,
	-- Draenor
	--[Continent.Draenor] = 8935,
	[Zone.FrostfireRidge] = 8937,
	[Zone.ShadowmoonValleyDraenor] = 8938,
	[Zone.Gorgrond] = 8939,
	[Zone.Talador] = 8940,
	[Zone.SpiresOfArak] = 8941,
	[Zone.NagrandDraenor] = 8942,
	-- Broken Isles
	--[Continent.BrokenIsles] = 11188,
	[Zone.Azsuna] = 10665,
	[Zone.Valsharah] = 10666,
	[Zone.Highmountain] = 10667,
	[Zone.Stormheim] = 10668,
	[Zone.Suramar] = 10669,
}

local exploreCoords = {
	[Zone.JadedForest] = {
		"48.0;45.0",	-- Dawn's Blossom,
		"41.2;21.5",	-- Tian Monastery,
		"52.1;90.8",	-- Dreamer's Pavillion,
		"50.0;26.2",	-- Emperor's Omen,
		"58.0;80.0",	-- Pearl Lake,
		"25.0;48.0",	-- Grookin Hill,
		"46.0;29.0",	-- Greenstone Quarry,
		"40.0;73.0",	-- Nectarbreeze Orchard,
		"25.0;37.0",	-- Camp Nooka Nooka,
		"40.0;13.0",	-- Terrace of Ten Thunders,
		"47.0;60.0",	-- Serpent's Heart,
		"52.0;82.0",	-- Slingtail Pits,
		"57.0;57.0",	-- Temple of the Jade Serpent,
		"57.0;44.0",	-- The Arboretum,
		"46.0;90.0",	-- Garrosh'ar Point,
		"65.0;30.0",	-- Windward Isle,
		"29.0;13.0",	-- Honeydew Village
	},
	[Zone.ValleyOfTheFourWinds] = {
		"50.1;75.1",	-- Winds' Edge,
		"13.0;75.5",	-- Dustback Gorge,
		"54.2;38.7",	-- Gilded Fan,
		"52.4;63.0",	-- The Imperial Granary,
		"56.1;49.8",	-- Halfhill,
		"19.0;57.0",	-- Stoneplow,
		"33.1;23.5",	-- Kunzen Village,
		"68.6;43.3",	-- Mudmug's Place,
		"16.1;82.7",	-- Nesingwary Safari,
		"16.6;38.7",	-- Paoquan Hollow,
		"60.7;27.6",	-- Pools of Purity,
		"73.2;58.3",	-- Rumbling Terrace,
		"65.2;57.4",	-- Silken Fields,
		"25.0;43.6",	-- Singing Marshes,
		"35.9;68.0",	-- Stormstout Brewery,
		"40.4;43.1",	-- The Heartland,
		"75.7;24.9",	-- Thunderfoot Ranch,
		"81.53;47.92",	-- Zhu's Descent
	},
	[Zone.KrasarangWilds] = {
		"68.0;44.2",	-- Anglers Wharf
		"31.2;63.2",	-- Cradle of Chi-Ji
		"65.3;32.9",	-- Dojan River
		"30.2;38.3",	-- Fallsong Village
		"80.6;25.6",	-- Krasarang Cove
		"68.5;22.8",	-- The Krasari Ruins
		"40.7;82.9",	-- Nayeli Lagoon
		"40.0;32.5",	-- Crane Wing Refuge
		"53.9;37.4",	-- Ruins of Dojan
		"24.0;47.1",	-- Ruins of Korja
		"39.1;56.8",	-- Temple of the Red Crane
		"45.5;31.8",	-- The Deepwild
		"14.1;39.0",	-- The Forbidden Jungle
		"12.7;59.9",	-- Southern Isle
		"43.3;90.2",	-- Unga Ingoo
		"76.6;8.7",		-- Zhu's Watch
	},
	[Zone.KunLaiSummit] = {
		"71.8;92.2",	-- Binan Village
		"45.4;86.2",	-- Firebough Nook
		"55.5;92.0",	-- Gate of the August Celestials
		"75.5;11.9",	-- Isle of Reckoning
		"38.0;75.1",	-- Kota Peak
		"58.0;74.8",	-- Mogujia
		"44.5;55.9",	-- Mount Neverest
		"68.1;73.2",	-- Muskpaw Ranch
		"49.3;42.9",	-- Peak of Serenity
		"36.7;47.9",	-- Shado-Pan Monastery
		"68.6;46.6",	-- Temple of the White Tiger
		"55.4;65.9",	-- The Burlap Trail
		"53.4;48.3",	-- Valley of Emperors
		"62.4;29.4",	-- Zouchin Village
	},
	[Zone.TownlongSteppes] = {
		"75.5;82.5",	-- Gao-Ran Battlefront
		"56.1;53.5",	-- Kri'vess
		"54.3;79.0",	-- Rensai's Watchpost
		"39.3;62.0",	-- Niuzao Temple
		"67.3;44.9",	-- Fire Camp Osul
		"82.5;72.4",	-- Hatred's Vice
		"49.2;71.0",	-- Shado-Pan Garrison
		"28.6;25.8",	-- Shan'ze Dao
		"44.6;77.5",	-- Sik'vess
		"71.3;70.5",	-- Slumprushes
		"26.3;39.1",	-- Sra'vess
	},
	[Zone.DreadWastes] = {
		"39.6;35.0",	-- Heart of Fear
		"53.6;34.9",	-- Klaxxi'vess
		"63.2;18.4",	-- Kypari Vor
		"59.2;60.6",	-- Kypari Zar
		"34.6;20.0",	-- Rikkitun Village
		"55.9;70.3",	-- Soggy's Gamble
		"68.3;30.4",	-- Terace of Gurthan
		"38.7;62.2",	-- The Briny Muck
		"46.2;34.5",	-- The Clutches of Shek'zeer
		"50.5;12.2",	-- The Sunset Brewgarden
		"66.0;42.2",	-- Writhingwood
		"30.5;73.6",	-- Zan'vess
	},
	[Zone.ValeOfEternalBlossoms] = {
		"26.6;37.2",	-- Ruins of Guo-Lai
		"36.3;72.0",	-- Mistfall Village
		"79.1;36.1",	-- Mogu'shan Palace
		"18.5;71.7",	-- Setting Sun Garrison
		"44.2;15.2",	-- The Golden Stair
		"86.4;62.5",	-- Shrine of Seven Stars
		"56.7;43.2",	-- The Golden Pagoda
		"48.3;69.1",	-- Tu Shen Burial Ground
		"62.0;22.6",	-- Shrine of Two Moons
		"40.5;47.0",	-- Whitepetal Lake
		"17.4;47.9",	-- The Five Sisters
	},
	[Zone.HellfirePeninsula] = {
		"26.9;62.3",	-- Falcon Watch
		"31.3;26.9",	-- Mag'har Post
		"62.0;17.8",	-- Throne of Kil'jaeden
		"55.4;38.7",	-- Thrallmar
		"70.1;73.6",	-- Zeth'Gor
		"27.5;77.0",	-- Den of Haal'esh
		"14.3;41.0",	-- Fallen Sky Ridge
		"79.1;72.9",	-- Void Ridge
		"45.3;82.5",	-- The Warp Fields
		"23.5;40.0",	-- Temple of Telhamat
		"54.3;84.3",	-- Expedition Armory
		"58.9;31.2",	-- Forge Camp: Mageddon
		"13.3;59.4",	-- Ruins of Sha'naar
		"70.0;50.4",	-- The Legion Front
		"87.7;50.3",	-- The Stair of Destiny
		"47.2;52.9",	-- Hellfire Citadel
		"54.8;64.5",	-- Honor Hold
		"41.2;32.6",	-- Pools of Aggonar
	},
	[Zone.TerokkarForest] = {
		"71.7;34.7",	-- Firewing Point
		"58.9;76.4",	-- Skettis
		"46.6;43.0",	-- Stonebreaker Hold
		"53.0;29.1",	-- Tuurem
		"29.1;23.3",	-- Shattrath City
		"66.5;52.3",	-- Bonechewer Ruins
		"37.5;49.6",	-- Refugee Caravan
		"43.8;20.2",	-- Cenarion Thicket
		"17.8;65.4",	-- Bleeding Hollow Ruins
		"60.6;40.2",	-- Raastok Glade
		"22.4;10.5",	-- The Barrier Hills
		"33.0;71.8",	-- Auchenai Grounds
		"24.4;59.9",	-- Veil Rhaze
		"49.1;66.0",	-- Writhing Mound
		"31.3;52.5",	-- Shadow Tomb
		"39.5;39.4",	-- Grangol'var Village
		"42.9;51.0",	-- Carrion Hill
		"57.1;56.6",	-- Allerian Stronghold
		"43.9;76.1",	-- Derelict Caravan
		"55.0;20.0",	-- Razorthorn Shelf
		"39.5;65.5",	-- Ring of Observance
	},
	[Zone.ShadowmoonValleyOutland] = {
		"45.3;26.3",	-- Coilskar Point
		"44.9;66.8",	-- Eclipse Point
		"70.8;85.7",	-- Netherwing Ledge
		"29.4;26.1",	-- Shadowmoon Village
		"49.8;41.2",	-- The Hand of Gul'dan
		"64.2;58.5",	-- Netherwing Fields
		"24.1;39.2",	-- Legion Hold
		"77.6;40.6",	-- The Black Temple
		"61.5;26.1",	-- Altar of Sha'tar
		"29.8;52.3",	-- Illidari Point
		"39.6;39.6",	-- The Deathforge
		"57.3;50.1",	-- Warden's Cage
		"35.5;60.2",	-- Wildhammer Stronghold
	},
	[Zone.NagrandOutland] = {
		"42.0;71.8",	-- Spirit Fields
		"33.5;44.7",	-- Sunspring Post
		"20.6;51.3",	-- Forge Camp: Fear
		"56.1;36.4",	-- Garadar
		"42.5;44.0",	-- Halaa
		"46.9;18.9",	-- Laughing Skull Ruins
		"65.8;54.0",	-- The Ring of Trials
		"29.7;24.6",	-- Warmaul Hill
		"62.5;64.3",	-- Clan Watch
		"25.9;37.1",	-- Forge Camp: Hate
		"33.6;15.6",	-- Zangar Ridge
		"74.3;52.9",	-- Windyreed Village
		"72.4;36.3",	-- Windyreed Pass
		"52.8;69.1",	-- Telaar
		"60.8;21.1",	-- Throne of the Elements
		"68.9;79.9",	-- Kil'sorrow Fortress
		"75.1;66.8",	-- Burning Blade Ruins
		"49.8;55.9",	-- Southwind Cleft
		"10.8;39.2",	-- The Twilight Ridge
	},
	[Zone.Zangarmarsh] = {
		"29.0;60.7",	-- Quagg Ridge
		"58.6;61.8",	-- The Lagoon
		"68.5;49.2",	-- Telredor
		"81.1;63.4",	-- Cenarion Refuge
		"44.9;66.3",	-- Feralfen Village
		"83.5;82.0",	-- Umbrafen Village
		"17.8;49.6",	-- Sporeggar
		"43.1;30.4",	-- Orebor Harborage
		"14.5;61.9",	-- The Spawning Glen
		"70.6;79.9",	-- Darkcrest Shore
		"82.5;37.5",	-- The Dead Mire
		"47.8;51.7",	-- Twin Spire Ruins
		"18.0;23.1",	-- Ango'rosh Grounds
		"21.7;39.6",	-- Marshlight Lake
		"18.6;8.0",		-- Ango'rosh Stronghold
		"62.7;41.2",	-- Bloodscale Grounds
		"31.8;52.3",	-- Zabra'jin
		"33.6;35.3",	-- Hewn Bog
	},
	[Zone.BladesEdgeMountains] = {
		"53.1;54.7",	-- Thunderlord Stronghold
		"77.1;75.2",	-- Vekhaar Stand
		"51.7;16.7",	-- Bash'ir Landing
		"65.9;36.8",	-- Bladed Gulch
		"55.6;26.2",	-- Bloodmaul Camp
		"60.0;35.3",	-- Ruuan Weald
		"68.0;10.8",	-- Crystal Spine
		"36.4;78.7",	-- Veil Lashh
		"30.5;59.5",	-- Vortex Summit
		"67.7;23.5",	-- Gruul's Lair
		"48.5;65.5",	-- Jagged Ridge
		"65.1;31.6",	-- Veil Ruuan
		"40.7;53.0",	-- Bladespire Hold
		"33.5;41.1",	-- Forge Camp: Wrath
		"56.0;69.0",	-- Razors Ridge
		"77.9;25.9",	-- Broken Wilds
		"53.6;43.9",	-- Circle of Blood
		"64.2;61.0",	-- Death's Door
		"74.7;41.8",	-- Forge Camp: Anger
		"73.9;62.6",	-- Mok'Nathal Village
		"31.9;27.5",	-- Raven's Wood
		"37.0;65.4",	-- Sylvanaar
		"72.0;22.9",	-- Skald
		"39.6;19.9",	-- Grishnath
		"46.3;77.2",	-- Bloodmaul Outpost
		"29.1;81.0",	-- Forge Camp: Terror
	},
	[Zone.Netherstorm] = {
		"48.8;84.5",	-- Manaforge Coruu
		"26.8;39.3",	-- Manaforge Ara
		"23.5;72.9",	-- Manaforge B'naar
		"54.4;21.3",	-- Ruins of Farahlon
		"28.4;77.5",	-- The Heap
		"56.0;77.8",	-- Sunfury Hold
		"45.1;35.8",	-- The Stormspire
		"75.8;62.5",	-- Tempest Keep
		"57.1;88.5",	-- Kirin'Var Village
		"46.1;9.6",		-- Eco-Dome Farfield
		"37.5;26.4",	-- Forge Base: Oblivion
		"22.3;55.9",	-- Gyro-Plank Bridge
		"45.3;53.7",	-- Eco-Dome Midrealm
		"29.9;16.0",	-- Socrethar's Seat
		"33.5;66.0",	-- Area 52
		"61.7;38.2",	-- Manaforge Ultris
		"39.7;73.5",	-- Arklon Ruins
		"59.6;68.2",	-- Maforge Duro
		"32.9;54.9",	-- Ruins of Enkaat
		"55.1;43.5",	-- Ethereum Staging Grounds
		"72.5;38.7",	-- Celestial Ridge
		"49.5;17.0",	-- Netherstone
	},
	[Zone.BoreanTundra] = {
		"87.6;25.1",	-- Temple City of En'kilah
		"66.3;28.5",	-- The Geyser Fields
		"27.9;51.6",	-- Garrosh's Landing
		"50.2;10.3",	-- Bor'gorok Outpost
		"47.4;81.1",	-- Riplash Stand
		"76.4;16.4",	-- The Dens of the Dying
		"50.2;24.3",	-- Steeljaw's Carvan
		"66.2;51.1",	-- Kaskala
		"82.4;46.4",	-- Death's Stand
		"46.1;34.8",	-- Amber Ledge
		"43.4;53.2",	-- Warsong Hold
		"57.7;69.3",	-- Valiance Keep
		"25.8;38.4",	-- Coldarra
	},
	[Zone.SholazarBasin] = {
		"65.9;60.1",	-- The Lifeblood Pillar
		"33.3;52.3",	-- The Suntouched Pillar
		"50.0;36.0",	-- The Glimmering Pillar
		"48.0;63.2",	-- River's Heart
		"74.5;34.6",	-- The Avalanche
		"29.7;40.1",	-- Makers' Perch
		"81.0;55.4",	-- Makers' Overlook
		"46.8;26.1",	-- The Savage Thicket
		"36.0;75.3",	-- The Mosslight Pillar
		"53.7;52.5",	-- Rainspeaker Canopy
		"24.3;81.7",	-- Kartak's Hold
		"24.5;33.5",	-- The Stormwright's Shelf
	},
	[Zone.Icecrown] = {
		"63.7;44.0",	-- The Bombardment
		"48.4;70.6",	-- Corp'rethar: The Horror Gate
		"74.0;37.7",	-- Sindragosa's Fall
		"36.5;24.1",	-- Valhalas
		"69.2;64.4",	-- The Broken Front
		"33.1;66.4",	-- The Fleshwerks
		"83.8;73.4",	-- Valley of Echoes
		"54.9;56.2",	-- Ymirheim
		"43.6;56.5",	-- The Conflagration
		"27.1;39.0",	-- Jotunheim
		"78.4;60.2",	-- Scourgeholme
		"44.4;22.6",	-- The Shadow Vault
		"54.2;85.8",	-- Icecrown Citadel
		"52.8;30.6",	-- Aldur'thar: The Desolation Gate
		"8.9;42.9",		-- Onslaught Harbor
	},
	[Zone.Dragonblight] = {
		"36.9;47.8",	-- Agmar's Hammer
		"82.5;70.7",	-- The Forgotten Shore
		"61.8;19.5",	-- The Crystal Vice
		"25.1;43.2",	-- Icemist Village
		"54.9;32.7",	-- Galakrond's Rest
		"13.8;46.2",	-- Westwind Refugee Camp
		"63.5;72.7",	-- Emerald Dragonshrine
		"39.7;67.0",	-- Lake Indu'le
		"71.0;75.2",	-- New Hearthglen
		"88.9;44.0",	-- Naxxramas
		"83.6;25.6",	-- Light's Trust
		"50.0;17.5",	-- Coldwind Heights
		"36.0;15.0",	-- Angrathar the Wrath Gate
		"77.1;60.0",	-- Venomspite
		"72.7;25.6",	-- Scarlet Point
		"38.4;31.9",	-- Obsidian Dragonshrine
		"59.7;49.8",	-- Wyrmrest Temple
	},
	[Zone.CrystalsongForest] = {
		"64.7;60.4",	-- The Unbound Thicket
		"13.1;33.9",	-- The Great Tree
		"14.5;44.1",	-- Violet Stand
		"75.2;83.0",	-- Windrunner's Overlook
		"16.0;15.4",	-- The Decrepit Flow
		"43.0;42.5",	-- Forlorn Woods
		"76.9;46.3",	-- Sunreaver's Command
		"26.4;61.4",	-- The Azure Front
	},
	[Zone.StormPeaks] = {
		"23.9;50.1",	-- Nidavelir
		"50.3;44.7",	-- Terrace of the Makers
		"47.8;68.2",	-- Brunnhildar Village
		"24.0;60.5",	-- Valkyrion
		"35.9;58.0",	-- Temple of Storms
		"35.3;68.7",	-- Bor's Breath
		"40.9;57.2",	-- Engine of the Makers
		"41.3;17.4",	-- Ulduar
		"72.9;48.5",	-- Thunderfall
		"27.3;41.9",	-- Snowdrift Plains
		"47.1;81.6",	-- Garm's Bane
		"29.4;73.8",	-- Frosthold
		"32.2;39.6",	-- Narvir's Cradle
		"35.1;84.0",	-- Sparksocket Minefield
		"64.8;44.8",	-- Temple of Life
		"64.4;59.1",	-- Dun Niffelem
	},
	[Zone.ZulDrak] = {
		"83.7;16.7",	-- Gundrak
		"28.2;45.1",	-- Voltarus
		"64.4;68.9",	-- Altar of Har'koa
		"48.2;56.4",	-- Ampitheater of Anguish
		"59.3;57.8",	-- Zim'Torga
		"21.1;75.2",	-- Zeramas
		"76.9;59.3",	-- Altar of Quetz'lun
		"41.7;76.8",	-- Drak'Sorta Fields
		"40.5;38.8",	-- Altar of Sseratus
		"53.3;36.5",	-- Altar of Rhunok
		"73.2;45.6",	-- Altar of Mam'toth
		"17.0;57.3",	-- Thrym's End
		"32.0;76.4",	-- Light's Breach
		"62.0;77.6",	-- Kolrama
	},
	[Zone.GrizzlyHills] = {
		"29.0;76.5",	-- Voldrune
		"15.8;49.6",	-- Granite Springs
		"64.9;45.6",	-- Camp Oneqwah
		"17.5;23.6",	-- Drak'Tharon Keep
		"31.4;57.9",	-- Amberpine Lodge
		"36.0;37.9",	-- Blue Sky Logging Grounds
		"21.3;65.3",	-- Conquest Hold
		"71.8;27.9",	-- Drakil'jin Ruins
		"77.9;59.3",	-- Dun Argol
		"48.2;42.2",	-- Grizzlemaw
		"50.3;57.2",	-- Rage Fang Shrine
		"68.1;14.8",	-- Thor Modan
		"14.5;84.4",	-- Venture Bay
		"56.8;28.4",	-- Westfall Brigade Encampment
	},
	[Zone.HowlingFjord] = {
		"30.3;41.4",	-- Westguard Keep
		"36.6;9.5",		-- Gjalerbron
		"47.8;12.1",	-- Camp Winterhoof
		"68.6;26.5",	-- Giant's Run
		"67.9;52.8",	-- Nifflevar
		"40.0;50.6",	-- Ember Clutch
		"78.2;46.2",	-- Ivald's Ruin
		"50.1;54.1",	-- Halgrind
		"45.1;33.1",	-- Skorn
		"54.2;16.8",	-- The Twisted Glade
		"58.3;45.9",	-- Utgarde Keep
		"66.6;39.1",	-- Baleheim
		"31.3;25.9",	-- Steel Gate
		"34.3;75.5",	-- Scalawag Point
		"52.9;69.0",	-- New Agamand
		"72.5;71.3",	-- Baelgun's Excavation Site
		"24.9;57.7",	-- Kamagua
		"27.0;24.1",	-- Apothecary Camp
		"78.1;27.3",	-- Vengeance Landing
		"60.7;12.8",	-- Fort Wildervar
		"57.6;35.9",	-- Cauldros Isle
	},
	[Zone.ShadowmoonValleyDraenor] = {
		"32.2;23.6",	-- Anguish Fortress
		"61.1;78.1",	-- Darktide Roost
		"52.3;26.7",	-- Elodor
		"38.6;33.4",	-- Embaari Village
		"40.3;26.5",	-- Gloomshade Grove
		"20.5;13.6",	-- Gul'var
		"61.2;45.3",	-- Karabor
		"40.0;66.0",	-- Shaz'gul
		"58.7;58.3",	-- The Shimmer Moor
		"42.9;69.9",	-- Socrethar's Rise
		"40.1;79.2",	-- Isle of Shadows
	},
	[Zone.Talador] = {
		"75.4;40.6",	-- Aruuna
		"54.6;69.6",	-- Auchindoun
		"71.6;57.7",	-- Duskfall Island
		"40.0;60.1",	-- Court of Souls
		"68.0;20.3",	-- Fort Wrynn
		"67.7;68.8",	-- Gordal Fortress
		"38.5;79.3",	-- Gul'rok
		"66.0;10.0",	-- The Path of Glory
		"51.8;26.8",	-- Orunai Coast
		"76.7;56.6",	-- Anchorite's Sojourn
		"41.4;43.0",	-- Shattrath City
		"50.6;86.7",	-- Telmor
		"58.9;64.8",	-- Tomb of Lights
		"63.3;37.4",	-- Tuurem
		"78.6;27.9",	-- Zangarra
	},
	[Zone.Gorgrond] = {
		"48.6;79.3",	-- Bastion Rise
		"45.4;71.1",	-- Beastwatch
		"54.4;33.3",	-- Grimrail Depot
		"53.9;65.0",	-- Crimson Fen
		"41.4;74.1",	-- Deadgrin
		"54.4;44.5",	-- Everbloom Wilds
		"42.2;77.5",	-- Evermorn Springs
		"46.4;45.2",	-- Gronn Canyon
		"52.9;60.7",	-- Highpass
		"61.0;51.7",	-- Iyun Weald
		"42.5;64.5",	-- Stonemaul Arena
		"50.3;70.7",	-- Tangleheart
		"43.3;20.9",	-- The Iron Approach
		"47.6;38.7",	-- The Pit
	},
	[Zone.FrostfireRidge] = {
		"27.4;32.1",	-- Bladespire Citadel
		"36.9;13.0",	-- Bloodmaul Stronghold
		"86.2;71.2",	-- Bones of Agurak
		"62.4;29.8",	-- Colossal's Fall
		"44.8;31.2",	-- Daggermaw Ravine
		"36.1;19.3",	-- Frostwind Crag
		"68.3;50.3",	-- Grimfrost Hill
		"65.7;58.0",	-- Grom'gar
		"83.7;59.4",	-- Iron Siegeworks
		"74.7;62.7",	-- Iron Waystation
		"68.1;32.0",	-- Magnarok
		"46.9;52.3",	-- Stonefang Outpost
		"46.5;47.4",	-- The Boneslag
		"54.6;44.1",	-- The Cracking Plains
		"23.8;54.9",	-- Wor'gol
	},
	[Zone.SpiresOfArak] = {
		"45.3;18.9",	-- Skettis
		"61.1;25.4",	-- The Howling Crag
		"36.8;44.0",	-- The Writhing Mire
		"57.8;85.6",	-- Pinchwhistle Point
		"61.2;55.2",	-- Veil Zekk
		"41.5;23.7",	-- Veil Akraz
		"41.7;59.9",	-- Southport
		"47.48;52.29",	-- Windswept Terrace
		"53.8;46.7",	-- Terrace of Dawn
		"61.9;37.3",	-- Sethekk Hollow
		"31.3;28.9",	-- Bladefist Hold
		"39.8;49.4",	-- Admiral Taylor's Garrison
		"73.4;37.9",	-- Lost Veil Anzu
		"61.3;70.0",	-- Pinchwhistle Gearworks
		"55.0;55.0",	-- Ravenskar
		"51.0;67.2",	-- Bloodmane Valley
		"41.2;46.8",	-- Axefall
	},
	[Zone.NagrandDraenor] = {
		"41.2;56.4",	-- Ancestral Grounds
		"50.4;19.3",	-- Broken Precipice
		"75.0;68.1",	-- Gates of Grommashar
		"84.4;56.4",	-- Hallvalor
		"37.4;32.4",	-- Highmaul Harbor
		"43.9;76.3",	-- Ironfist Harbor
		"53.4;43.3",	-- Lok-rath
		"80.5;67.1",	-- Mar'gok's Overwatch
		"42.7;33.2",	-- Mok'gol Watchpost
		"47.2;61.0",	-- Oshu'gun
		"69.0;64.2",	-- Telaar
		"57.0;19.0",	-- The Ring of Blood
		"79.7;49.8",	-- The Ring of Trials
		"73.2;20.8",	-- Throne of the Elements
		"86.3;27.6",	-- Zangar Shore
	},
	[Zone.Deepholm] = {
		"26.3;69.5",	-- Stonehearth
		"56.6;10.9",	-- Therazane's Throne
		"39.8;18.6",	-- The Pale Roost
		"39.2;69.1",	-- Masters' Gate
		"74.2;40.7",	-- Crimson Expanse
		"26.8;32.6",	-- Needlerock Chasm
		"21.7;47.7",	-- Needlerock Slag
		"55.8;75.4",	-- Storm's Fury Wreckage
		"49.0;49.0",	-- Temple of Earth
		"35.2;80.3",	-- The Quaking Fields
		"62.9;58.5",	-- Deathwing's Fall
		"68.3;77.8",	-- Twilight Overlook
	},
	[Zone.Vashjir] = {
		"22.1;80.2",	-- Abandoned Reef
		"71.5;29.8",	-- Abyssal Breach
		"39.4;19.3",	-- Deepfin Ridge
		"54.1;63.9",	-- Korthun's End
		"32.3;54.1",	-- L'ghorek
		"43.6;48.4",	-- Glimmerdeep Gorge
		"61.5;58.9",	-- Gnaws' Boneyard
		"54.9;43.5",	-- Seabrush
		"53.2;56.2",	-- Gurboggle's Ledge
		"58.8;81.4",	-- The Clutch
		"39.7;29.7",	-- Legion's Fate
		"55.4;83.0",	-- Beth'mora Ridge
		"59.2;56.5",	-- Nespirah
		"33.7;72.4",	-- Ruins of Vashj'ir
		"47.9;37.8",	-- Silver Tide Hollow
		"42.2;70.0",	-- Underlight Canyon
		"64.8;49.3",	-- The Skeletal Reef
		"50.3;24.1",	-- Seafarer's Tomb
		"66.4;41.7",	-- Ruins of Thelserai Temple
		"47.0;24.0",	-- The Scalding Chasm
		"50.9;21.5",	-- Shimmering Grotto
	},
	[Zone.CapeOfStranglethorn] = {
		"39.7;71.0",	-- Booty Bay
		"62.4;28.1",	-- Crystalvein Mine
		"46.3;22.5",	-- Gurubashi Arena
		"34.1;32.4",	-- Hardwrench Hideaway
		"60.8;81.6",	-- Jaquero Isle
		"54.4;30.3",	-- Ruins of Jubuwal
		"43.5;81.4",	-- The Wild Shore
		"50.5;58.1",	-- Mistvale Valley
		"43.0;49.1",	-- Nek'mani Wellspring
		"62.2;43.7",	-- Ruins of Aboraz
	},
	[Zone.NorthernStranglethorn] = {
		"46.7;9.5",		-- Rebel Camp
		"26.4;20.2",	-- Ruins of Zul'Kunda
		"46.1;52.9",	-- Mizjah Ruins
		"37.8;48.4",	-- Grom'gol Base Camp
		"44.1;19.8",	-- Nesingwary's Expedition
		"34.3;36.2",	-- Bal'lal Ruins
		"33.0;42.5",	-- The Vile Reef
		"83.9;32.5",	-- Zul'Gurub
		"51.48;34.05",	-- Lake Nazferiti
		"42.2;38.4",	-- Kal'ai Ruins
		"60.2;19.9",	-- Kurzen's Compound
		"66.9;50.9",	-- Mosh'Ogg Ogre Mound
		"59.0;55.2",	-- Balia'mah Ruins
		"64.7;39.7",	-- Bambala
		"19.2;25.6",	-- Zuuldaia Ruins
		"53.2;66.0",	-- Fort Livingston
	},
	[Zone.Westfall] = {
		"54.4;32.3",	-- Saldean's Farm
		"44.9;82.0",	-- The Dagger Hills
		"42.4;65.5",	-- Moonbrook
		"61.5;59.2",	-- The Dead Acre
		"55.9;49.3",	-- Sentinel Hill
		"57.7;15.8",	-- The Jansen Stead
		"44.9;23.9",	-- Jangolode Mine
		"38.2;52.3",	-- Alexston Farmstead
		"64.0;72.0",	-- The Dust Plains
		"45.3;34.9",	-- Molsen Farm
		"33.9;73.6",	-- Demont's Place
		"51.0;21.4",	-- Furlbrow's Pumpkin Farm
		"39.2;43.2",	-- The Raging Chasm
	},
	[Zone.Duskwood] = {
		"74.5;46.2",	-- Darkshire
		"35.8;72.7",	-- Vul'Gol Ogre Mound
		"51.0;74.0",	-- The Yorgen Farmstead
		"64.7;37.7",	-- Brightwood Grove
		"79.7;66.1",	-- Tranquil Gardens Cemetery
		"54.6;21.2",	-- The Darkened Bank
		"21.4;69.9",	-- Addle's Stead
		"10.1;44.3",	-- The Hushed Bank
		"77.1;35.9",	-- Manor Mistmantle
		"19.8;55.2",	-- Raven Hill
		"19.6;41.3",	-- Raven Hill Cemetery
		"63.8;71.9",	-- The Rotting Orchard
	},
	[Zone.DeadwindPass] = {
		"45.1;35.8",	-- Deadman's Crossing
		"58.6;64.7",	-- The Vice
		"42.6;68.8",	-- Karazhan
	},
	[Zone.BlastedLands] = {
		"60.3;28.4",	-- Serpent's Coil
		"52.61;18.63",	-- Nethergarde Supply Camps
		"39;32",		-- Altar of Storms
		"54.4;52.9",	-- The Dark Portal
		"47.1;40.1",	-- Dreadmaul Post
		"32.3;45.7",	-- The Tainted Scar
		"64.3;15.8",	-- Nethergarde Keep
		"45.1;26.7",	-- Rise of the Defiler
		"69.1;33.5",	-- Shattershore
		"50.7;70.9",	-- Sunveil Excursion
		"44.5;86.1",	-- Surwich
		"39.5;12.9",	-- Dreadmaul Hold
		"34.2;72.3",	-- The Tainted Forest
		"65.8;78.0",	-- The Red Reaches
	},
	[Zone.SwampOfSorrows] = {
		"47.1;54.2",	-- Stonard
		"67.8;74.9",	-- Stagalbog
		"84.2;38.9",	-- Sorrowmurk
		"77.3;13.7",	-- Misty Reed Strand
		"72.3;12.8",	-- Bogpaddle
		"14.7;35.8",	-- Misty Valley
		"28.8;32.1",	-- The Harborage
		"22.3;49.4",	-- Splinterspear Junction
		"62.6;50.0",	-- Pool of Tears
		"48.8;42.1",	-- The Shifting Mire
		"68.4;35.8",	-- Marshtide Watch
		"18.6;68.1",	-- Purespring Cavern
	},
	[Zone.RedridgeMountains] = {
		"60.9;52.5",	-- Stonewatch Keep
		"70.28;34.66",	-- Galardell Valley
		"25.5;43.4",	-- Lakeshire
		"19.7;59.1",	-- Three Corners
		"35.1;12.8",	-- Render's Camp
		"47.2;39.2",	-- Alther's Mill
		"41.9;52.6",	-- Lake Everstill
		"71.25;54.57",	-- Stonewatch Falls
		"64.7;71.3",	-- Render's Valley
		"38.2;68.5",	-- Lakeridge Highway
		"30.2;26.1",	-- Redridge Canyons
		"53.4;54.7",	-- Camp Everstill
		"81.0;62.4",	-- Shalewind Canyon
	},
	[Zone.ElwynnForest] = {
		"52.9;66.2",	-- Crystal Lake
		"74.0;51.5",	-- Stone Cairn Lake
		"69.4;79.4",	-- Brackwell Pumpkin Patch
		"64.6;69.3",	-- Tower of Azora
		"42.1;64.7",	-- Goldshire
		"39.5;80.3",	-- Fargodeep Mine
		"83.5;66.9",	-- Eastvale Logging Camp
		"84.8;79.4",	-- Ridgepoint Tower
		"50.4;42.5",	-- Northshire Valley
		"48.5;85.8",	-- Jerod's Landing
		"24.5;73.3",	-- Westbrook Garrison
	},
	[Zone.BurningSteppes] = {
		"73.9;53.4",	-- Terror Wing Path
		"66.7;77.5",	-- Blackrock Pass
		"36.1;53.5",	-- Black Tooth Hovel
		"9.4;27.5",		-- Altar of Storms
		"20.7;29.2",	-- Blackrock Mountain
		"69.7;40.5",	-- Dreadmaul Rock
		"73.5;68.0",	-- Morgan's Vigil
		"24.3;57.7",	-- The Whelping Downs
		"56.6;37.4",	-- Ruins of Thaurissan
		"32.3;36.5",	-- Blackrock Stronghold
	},
	[Zone.Badlands] = {
		"46.5;57.4",	-- Agmond's End
		"27.4;38.0",	-- The Dustbowl
		"60.1;20.7",	-- Camp Kosh
		"17.2;63.0",	-- Camp Cagg
		"38.3;11.6",	-- Uldaman
		"31.7;54.6",	-- Scar of the Worldbreaker
		"52.3;51.2",	-- Bloodwatcher Point
		"17.7;41.7",	-- New Kargath
		"68.0;48.2",	-- Lethlor Ravine
		"41.1;26.5",	-- Angor Fortress
	},
	[Zone.SearingGorge] = {
		"62;62.3",		-- Grimesilt Dig Site
		"52.7;49.6",	-- The Cauldron
		"21.2;80.1",	-- Balckchar Cave
		"48.0;70.0",	-- The Sea of Cinders
		"23.8;31.8",	-- Firewatch Ridge
		"71.8;26.8",	-- Dustfire Valley
		"39.9;82.9",	-- Blackrock Mountain
		"37.7;29.9",	-- Thorium Point
	},
	[Zone.DunMorogh] = {
		"71.5;46.2",	-- Amberstill Ranch
		"84.1;51.8",	-- Helm's Bed Lake
		"59.6;33.8",	-- Gates of Ironforge
		"48.3;37.9",	-- Shimmer Ridge
		"76.5;57.2",	-- Gol'Bolar Quarry
		"90.3;37.6",	-- North Gate Outpost
		"31.5;51.9",	-- Frostmane Hold
		"41.4;40.2",	-- Iceflow Lake
		"53.6;50.5",	-- Kharanos
		"67.2;53.9",	-- The Tundrid Hills
		"43.9;64.5",	-- Coldridge Pass
		"34.6;75.6",	-- Coldridge Valley
		"58.6;57.7",	-- Frostmane Front
		"78.0;24.2",	-- Ironforge Airfield
		"33.8;37.5",	-- New Tinkertown
	},
	[Zone.LochModan] = {
		"38.0;60.7",	-- Grizzlepaw Ridge
		"71.0;23.8",	-- Mo'grosh Stronghold
		"48.40;17.55",	-- The Loch
		"35.2;47.6",	-- Thelsamar
		"32.5;78.3",	-- Stonesplinter Valley
		"20.3;78.5",	-- Valley of Kings
		"20.2;17.1",	-- North Gate Pass
		"82.3;65.0",	-- The Farstrider Lodge
		"69.4;65.3",	-- Ironband's Excavation Site
		"48.0;11.4",	-- Stonewrought Dam
		"34.8;21.5",	-- Silver Stream Mine
	},
	[Zone.TwilightHighlands] = {
		"62.7;46.0",	-- Gorshak War Camp
		"54.0;62.9",	-- Highland Forest
		"64.4;78.9",	-- Obsidian Forest
		"50.2;29.1",	-- Thundermar
		"38.3;29.0",	-- Glopgut's Hollow
		"43.2;58.1",	-- Victor's Point
		"47.8;10.6",	-- The Maw of Madness
		"76.0;53.0",	-- Dragonmaw Port
		"28.18;37.67",	-- Dragonmaw Pass
		"80.7;76.8",	-- Highbank
		"39.9;46.6",	-- The Twilight Breach
		"54.1;42.7",	-- Bloodgulch
		"50.7;56.9",	-- Crucible of Carnage
		"49.5;68.8",	-- Dunwald Ruins
		"59.9;57.0",	-- Firebeard's Patrol
		"18.9;51.4",	-- Grim Batol
		"46.1;77.2",	-- Crushblow
		"29.0;47.8",	-- Wyrms' Bend
		"71.0;70.9",	-- Twilight Shore
		"25.3;21.0",	-- Vermillion Redoubt
		"44.3;27.3",	-- Humboldt Conflagration
		"54.9;17.3",	-- Kirthaven
		"43.6;18.1",	-- Ruins of Drakgor
		"71.0;38.8",	-- Slithering Cove
		"57.9;30.3",	-- The Black Breach
		"36.39;38.03",	-- The Gullet
		"76.8;14.5",	-- The Krazzworks
	},
	[Zone.Wetlands] = {
		"18.9;36.0",	-- Bluegill Marsh
		"48.5;48.0",	-- Angerfang Encampment
		"19.3;46.9",	-- Black Channel Marsh
		"35.8;48.9",	-- Whelgar's Excavation Site
		"32.5;17.6",	-- Saltspray Glen
		"43.6;25.9",	-- Ironbeard's Tomb
		"24.5;24.3",	-- Sundown Marsh
		"46.9;16.5",	-- Dun Modr
		"61.9;56.6",	-- Mosshide Fen
		"67.9;34.9",	-- Raptor Ridge
		"10.2;58.2",	-- Menethil Harbor
		"60.87;25.46",	-- Direforge Hill
		"50.0;76.4",	-- Dun Algaz
		"57.9;40.6",	-- Greenwarden's Grove
		"52.2;61.4",	-- Thelgen Rock
		"58.4;71.0",	-- Slabchisel's Survey
	},
	[Zone.ArathiHighlands] = {
		"13.0;36.4",	-- Galen's Fall
		"49.1;78.9",	-- Boulderfist Hall
		"23.8;81.8",	-- Faldir's Cove
		"39.8;46.4",	-- Refuge Pointe
		"16.5;64.1",	-- Stromgarde Keep
		"59.3;32.8",	-- Circle of East Binding
		"47.3;51.4",	-- Circle of Outer Binding
		"18.97;30.99",	-- Circle of West Binding
		"27.0;27.1",	-- Northfold Manor
		"69.3;37.2",	-- Hammerfall
		"30.1;59.3",	-- Circle of Inner Binding
		"41.3;91.0",	-- Thandol Span
		"61.6;70.3",	-- Witherbark Village
		"56.4;57.6",	-- Go'Shek Farm
		"49.9;41.3",	-- Dabyrie's Farmstead
		"27.5;44.2",	-- Boulder'gor
	},
	[Zone.HillsbradFoothills] = {
		"50.16;24.37",	-- Crushridge Hold
		"34.0;73.8",	-- Azurelode Mine
		"44.9;9.1",		-- Dandred's Fold
		"46.3;54.1",	-- Darrow Hill
		"49.88;32.59",	-- Gallows' Corner
		"43.2;38.5",	-- Growless Cave
		"40.0;47.6",	-- Gavin's Naze
		"62.83;84.80",	-- Dun Garok
		"30.4;36.2",	-- Dalaran Crater
		"68.3;60.0",	-- Durnholde Keep
		"36.56;58.04",	-- The Sludge Fields
		"49.6;46.7",	-- Corrahn's Dagger
		"27.0;85.6",	-- Purgation Isle
		"45.3;29.0",	-- Ruins of Alterac
		"58.3;23.4",	-- Strahnbrad
		"55.6;38.5",	-- Sofera's Naze
		"49.43;18.88",	-- Slaughter Hollow
		"33.8;46.5",	-- Brazie Farmstead
		"29.5;63.6",	-- Southpoint Gate
		"48.97;71.89",	-- Ruins of Southshore
		"56.7;46.9",	-- Tarren Mill
		"44.2;48.6",	-- The Headland
		"52.4;12.6",	-- The Uplands
		"68.1;32.9",	-- Chillwind Point
		"35.06;26.14",	-- Misty Shore
		"57.51;74.96",	-- Nethander Stead
	},
	[Zone.SilverpineForest] = {
		"62.0;8.7",		-- Forsaken High Command
		"69.1;26.8",	-- Fenris Isle
		"56.5;34.7",	-- The Decrepit Fields
		"50.9;66.6",	-- The Forsaken Front
		"34.8;12.4",	-- The Skittering Dark
		"59.3;45.4",	-- Deep Elem Mine
		"42.2;63.2",	-- Shadowfang Keep
		"37.3;28.0",	-- North Tide's Beachead
		"53.2;25.6",	-- Valgan's Field
		"45.0;40.0",	-- The Sepulcher
		"46.1;51.0",	-- Olsen's Farthing
		"61.2;62.4",	-- Ambermill
		"46.1;79.5",	-- The Battlefront
		"44.66;21.64",	-- North Tide's Run
		"44.9;18.8",	-- Forsaken Rear Guard
	},
	[Zone.TrisfalGlades] = {
		"87.00;47.2",	-- Venomweb Vale
		"78.4;26.9",	-- Scarlet Watch Post
		"38.4;48.9",	-- Solliden Farmstead
		"68.3;45.0",	-- Brightwater Lake
		"53.8;58.7",	-- Cold Hearth Manor
		"56.9;35.6",	-- Garren's Haunt
		"73.7;60.0",	-- Balnir Farmstead
		"79.1;54.7",	-- Crusader Outpost
		"45.1;65.4",	-- Nightmare Vale
		"32.2;63.8",	-- Deathknell
		"45.6;32.9",	-- Agamand Mills
		"59.7;50.9",	-- Brill
		"61.87;67.55",	-- Ruins of Lordaeron
		"85.08;31.34",	-- Scarlet Monastery Entrance
		"84.9;69.4",	-- The Bulwark
		"46.2;51.4",	-- Calston Estate
	},
	[Zone.WesternPlaguelands] = {
		"36.5;54.6",	-- Felstone Field
		"64.4;40.1",	-- The Weeping Cave
		"47.63;67.18",	-- Andorhal
		"69.6;50.7",	-- Thondroril River
		"45.1;51.2",	-- Dalson's Farm
		"63.9;58.2",	-- Gahrron's Withering
		"44.9;17.0",	-- Hearthglen
		"54.6;85.5",	-- Sorrow Hill
		"60.03;74.66",	-- Darrowmere Lake
		"68.3;81.1",	-- Caer Darrow
		"54.9;66.2",	-- The Writhing Haunt
		"47.2;33.4",	-- Northridge Lumber Camp
		"27.0;57.7",	-- The Bulwark
		"46.0;45.5",	-- Redpine Dell
	},
	[Zone.Hinterlands] = {
		"73.2;54.2",	-- Shaol'watha
		"13.9;45.0",	-- Aerie Peak
		"23.46;58.21",	-- Zun'watha
		"49.0;52.1",	-- The Creeping Ruin
		"48.4;66.9",	-- The Altar of Zul
		"34.6;72.0",	-- Shadra'Alor
		"46.59;39.68",	-- Agol'watha
		"33.3;45.6",	-- Quel'Danil Lodge
		"62.7;24.1",	-- Seradane
		"72.7;66.1",	-- The Overlook Cliffs
		"57.6;42.6",	-- Skulk Rock
		"63.1;74.7",	-- Jintha'Alor
		"23.1;33.5",	-- Plaguemist Ravine
		"40.5;59.3",	-- Valorwind Lake
	},
	[Zone.EasternPlaguelands] = {
		"35.1;84.2",	-- Darrowshire
		"48.90;62.25",	-- The Infectis Scar
		"66.4;10.3",	-- Zul'Mashar
		"68.7;56.5",	-- Pestilent Scar
		"55.6;62.9",	-- Corin's Crossing
		"33.6;24.4",	-- Plaguewood
		"12.5;26.3",	-- Terrordale
		"35.7;68.5",	-- Crown Guard Tower
		"36.1;44.8",	-- The Fungal Vale
		"57.4;74.1",	-- Lake Mereldar
		"78.1;35.8",	-- The Noxious Glade
		"08.63;66.20",	-- Thondroril River
		"24.0;78.8",	-- The Undercroft
		"62.4;41.7",	-- Eastwall Tower
		"66.1;25.0",	-- Northdale
		"50.5;20.5",	-- Northpass Tower
		"75.6;75.2",	-- Tyr's Hand
		"76.8;53.9",	-- Light's Hope Chapel
		"48.1;13.1",	-- Quel'Lithien Lodge
		"26.8;9.8",		-- Statholme
		"46.3;43.5",	-- Blackwood Lake
		"87.1;78.5",	-- Ruins of the Scarlet Enclave
		"22.6;66.0",	-- The Marris Stead

	},
	[Zone.Ghostlands] = {--858
		"48.2;84.3",	-- Thalassian Pass
		"33.1;79.9",	-- Deatholme
		"12.4;57.0",	-- Windrunner Spire
		"17.9;41.4",	-- Windrunner Village
		"25.0;15.0",	-- Goldenmist Village
		"33.4;32.2",	-- Sanctum of the Moon
		"34.3;47.6",	-- Bleeding Ziggurat
		"40.4;49.8",	-- Howling Ziggurat
		"47.12;32.8",	-- Tranquillien
		"54.7;49.7",	-- Sanctum of the Sun
		"66.6;58.9",	-- Zeb'Nowa
		"77.3;64.4",	-- Amani Pass
		"77.2;32.1",	-- Farstrider Enclave
		"78.6;18.7",	-- Dawnstart Spire
		"60.46;11.7",	-- Suncrown Village
		"48.39;11.51",	-- Elrendar Crossing
	},
	[Zone.EversongWoods] = {
		"55.7;56.4",	-- Stillwhisper Pond
		"29.4;69.3",	-- Sunsail Anchorage
		"52.3;73.1",	-- East Sanctum
		"69.27;46.54",	-- Duskwither Grounds
		"43.9;73.7",	-- Fairbreeze Village
		"52.4;39.4",	-- Silvermoon City
		"65.9;78.6",	-- Lake Elrendar
		"72.0;79.3",	-- Tor'Watha
		"44.1;85.8",	-- Runestone Falithas
		"55.8;84.2",	-- Rusestone Shan'dor
		"62.2;79.3",	-- Zeb'Watha
		"64.6;73.1",	-- Elreandar Falls
		"38.3;73.5",	-- Saltheril's Haven
		"35.3;57.6",	-- West Sanctum
		"28.5;57.8",	-- Tranquil Shore
		"31.3;16.0",	-- Sunstrider Isle
		"36.2;86.0",	-- The Scorched Grove
		"54.2;71.9",	-- The Living Wood
		"71.6;45.3",	-- Azurebreeze Coast
		"60.6;54.2",	-- Thuron's Livery
		"42.9;39.3",	-- Ruins of Silvermoon
		"42.7;50.4",	-- North Sanctum
		"61.2;63.7",	-- Farstrider Rereat
		"33.4;77.6",	-- Goldenbough Pass
		"23.5;74.8",	-- Golden Strand
	},
	[Zone.IsleOfQuelDanas] = {
		"47.4;30.6",	-- Isle of Quel'Danas
	},
	[Zone.Durotar] = {
		"54.0;9.0",		-- Skull Rock
		"44.5;62.2",	-- Valley of Trials
		"56.1;75.8",	-- Sen'jin Village
		"53.5;43.4",	-- Razor Hill
		"52.4;24.2",	-- Drygulch Ravine
		"45.4;8.5",		-- Orgrimmar
		"66.6;82.9",	-- Echo Isles
		"40.3;24.7",	-- Thunder Ridge
		"58.1;60.2",	-- Tiragarde Keep
		"44.6;50.6",	-- Razormane Grounds
		"40.5;40.0",	-- Southfury Watershed
		"48.5;79.1",	-- Northwatch Foothold
	},
	[Zone.NorthernBarrens] = {
		"67.2;12.1",	-- Boulder Lode Mine
		"67.93;72.28",	-- Ratchet
		"55.7;78.6",	-- The Stagnant Oasis
		"67.0;41.3",	-- Far Watch Post
		"25.5;31.7",	-- The Dry Hills
		"36.8;45.9",	-- The Forgotten Pools
		"54.9;41.1",	-- Grol'dom Farm
		"70.3;84.1",	-- The Merchant Coast
		"55.7;18.5",	-- The Sludge Fen
		"43.1;35.4",	-- Dreadmist Peak
		"58.8;50.0",	-- Thorn Hill
		"50.2;57.3",	-- The Crossroads
		"40.3;73.9",	-- Lushwater Oasis
		"39.6;14.1",	-- The Mor'shan Rampart
	},
	[Zone.SouthernBarrens] = {
		"50.7;84.0",	-- Bael Modan
		"46.17;68.15",	-- Battlescar
		"39.3;22.3",	-- Hunter's Hill
		"44.9;54.3",	-- Ruins of Taurajo
		"42.4;44.0",	-- Vendetta Point
		"38.51;88.95",	-- Razorfen Kraul
		"36.5;11.1",	-- Honor's Stand
		"41.0;78.2",	-- Frazzlecraz Motherlode
		"52.2;48.6",	-- Forward Command
		"68.8;49.1",	-- Northwatch Hold
		"47.8;33.68",	-- The Overgrowth
	},
	[Zone.DustwallowMarsh] = {
		"76.0;17.5",	-- Alcaz Island
		"67.1;49.8",	-- Theramore Isle
		"36.3;30.4",	-- Brackenwall Village
		"61.5;30.2",	-- Dreadmurk Shore
		"43.4;75.5",	-- Wyrmbog
		"41.4;12.4",	-- Blackhoof Village
		"46.6;46.1",	-- Direhorn Post
		"41.4;75.1",	-- Mudsprocket
		"29.7;49.0",	-- Shady Rest Inn
	},
	[Zone.ThousandNeedles] = {
		"32.1;18.3",	-- The Great Lift
		"13.1;37.5",	-- Highperch
		"70.44;61.19",	-- The Shimmering Deep
		"47.0;50.7",	-- Freewind Post
		"33.6;38.6",	-- Darkcloud Pinnacle
		"92.4;78.8",	-- Southsea Holdfast
		"31.1;58.8",	-- Twilight Bulwark
		"13.4;10.3",	-- Westreach Summit
		"67.1;85.7",	-- Sunken Dig Site
		"51.7;30.0",	-- Razorfen Downs
		"88.4;47.8",	-- Splithoof Heights
		"54.9;63.2",	-- The Twilight Withering
	},
	[Zone.Tanaris] = {
		"37.8;77.7",	-- Valley of the Watchers
		"71.6;49.4",	-- Lost Rigger Cove
		"34.3;45.3",	-- The Noxious Lair
		"41.0;55.5",	-- Dunemaul Compound
		"53.7;67.6",	-- The Gaping Chasm
		"53.6;91.7",	-- Land's End Beach
		"30.4;66.4",	-- Thistleshrub Valley
		"37.3;14.3",	-- Zul'Farrak
		"52.3;45.4",	-- Broken Pillar
		"47.2;64.9",	-- Eastmoon Ruins
		"50.0;28.0",	-- Gadgetzan
		"64.2;50.0",	-- Caverns of Time
		"40.8;70.6",	-- Southmoon Ruins
		"40.9;27.3",	-- Sandsorrow Watch
		"55.1;40.9",	-- Abyssal Sands
		"63.0;59.2",	-- Southbreak Shore
	},
	[Zone.UnGoroCrater] = {
		"67.9;54.8",	-- The Marshlands
		"51.1;77.5",	-- The Slithering Scar
		"34.4;54.0",	-- Golakka Hot Springs
		"33.2;70.7",	-- Terror Run
		"77.1;39.2",	-- Ironstone Plateau
		"54.5;48.0",	-- Fire Plume Ridge
		"51.4;25.6",	-- Lakkari Tar Pits
		"65.7;14.3",	-- Fungal Rock
		"54.0;60.9",	-- Marshal's Stand
		"42.2;41.7",	-- Mossy Pile
		"39.2;34.3",	-- The Roiling Gardens
		"29.0;35.8",	-- The Screaming Reaches
	},
	[Zone.Uldum] = {
		"63.9;73.3",	-- Lost City of the Tol'vir
		"54.3;52.2",	-- Akhenet Fields
		"33.7;30.9",	-- Temple of Uldum
		"72.16;44.35",	-- Tombs of the Precursors
		"20.8;61.8",	-- Schnottz's Landing
		"64.5;16.1",	-- Khartut's Tomb
		"60.5;39.2",	-- Tahret Grounds
		"84.7;52.8",	-- The Cursed Landing
		"45.6;56.2",	-- Obelisk of the Sun
		"80.3;60.0",	-- The Trail of Devastation
		"43.7;70.4",	-- Cradle of the Ancients
		"49.0;38.4",	-- Mar'at
		"67.1;40.9",	-- Nahorn
		"51.2;82.0",	-- Neferset City
		"40.8;22.9",	-- Obelisk of the Moon
		"64.6;31.8",	-- Obelisk of the Stars
		"40.5;39.9",	-- Orsis
		"54.8;32.4",	-- Ramkahen
		"46.1;15.5",	-- Ruins of Ahmtul
		"32.1;65.5",	-- Ruins of Ammon
		"69.0;21.8",	-- The Gate of Unending Cycles
		"58.3;40.9",	-- Vir'naal Dam
	},
	[Zone.Silithus] = {
		"60.0;71.7",	-- Hive'Regal
		"32.0;78.9",	-- The Scarab Wall
		"30.9;16.0",	-- The Crystal Vale
		"49.4;22.4",	-- Hive'Ashi
		"54.4;34.2",	-- Cenarion Hold
		"31.4;53.8",	-- Hive'Zora
		"65.3;47.4",	-- Southwind Village
		"81.3;17.8",	-- Valor's Rest
	},
	[Zone.Feralas] = {
		"75.9;62.4",	-- The Writhing Deep
		"58.6;73.0",	-- Ruins of Isildien
		"45.8;49.6",	-- Feathermoon Stronghold
		"49.7;49.2",	-- The Forgotten Coast
		"55.4;56.2",	-- Feral Scar Vale
		"68.7;40.3",	-- Grimtotem Compound
		"83.0;40.9",	-- Lower Wilds
		"76.5;44.4",	-- Camp Mojache
		"60.4;35.6",	-- Dire Maul
		"75.6;29.8",	-- Gordunni Outpost
		"67.7;58.5",	-- Darkmist Ruins
		"28.5;49.1",	-- Ruins of Feathermoon
		"46.3;17.9",	-- The Twin Colossals
	},
	[Zone.Desolace] = {
		"51.5;10.0",	-- Tethris Aran
		"50.7;59.0",	-- Kodo Graveyard
		"80.3;79.3",	-- Shadowbreak Ravine
		"51.3;78.5",	-- Mannoroc Coven
		"29.9;29.4",	-- Slitherblade Shore
		"35.34;57.2",	-- Valley of Spears
		"70.6;74.8",	-- Shok'Thokar
		"36.1;88.6",	-- Gelkis Village
		"24.2;70.9",	-- Shadowprey Village
		"66.7;8.7",		-- Nijel's Point
		"78.2;21.6",	-- Sargeron
		"54.5;25.2",	-- Thunder Axe Fortress
		"56.1;47.3",	-- Cenarion Wildlands
		"74.7;45.6",	-- Magram Territory
		"28.7;9.01",	-- Ranazjar Isle
		"36.5;69.9",	-- Thargad's Camp
	},
	[Zone.Mulgore] = {
		"62.7;42.6",	-- The Venture Co. Mine
		"47.8;58.4",	-- Bloodhoof Village
		"53.8;85.8",	-- Red Cloud Mesa
		"54.2;47.9",	-- Ravaged Caravan
		"51.14;09.25",	-- Windfury Ridge
		"61.1;60.5",	-- The Rolling Plains
		"32.3;50.6",	-- Bael'dun Digsite
		"35.5;61.3",	-- Palemane Rock
		"53.7;66.7",	-- Winterhoof Water Well
		"44.9;43.5",	-- Thunderhorn Water Well
		"54.2;20.9",	-- The Golden Plains
		"59.82;19.9",	-- Red Rocks
		"43.1;14.2",	-- Wildmane Water Well
	},
	[Zone.StonetalonMountains] = {
		"45.1;30.2",	-- Cliffwalker Post
		"31.6;71.5",	-- The Charred Vale
		"63.4;88.7",	-- Boulderslide Ravine
		"51.6;47.3",	-- Mirkfallon Lake
		"37.0;54.3",	-- Battlescar Valley
		"69.6;85.1",	-- Greatwood Vale
		"66.9;49.3",	-- Windshear Crag
		"49.3;63.4",	-- Sun Rock Retreat
		"72.6;92.4",	-- Malaka'jin
		"40.9;19.9",	-- Stonetalon Peak
		"59.6;78.9",	-- Webwinder Path
		"59.1;57.7",	-- Windshear Hold
		"35.8;31.5",	-- Thal'darah Overlook
		"48.8;76.3",	-- Ruins of Eldre'thar
		"76.7;75.8",	-- Unearthed Grounds
		"57.2;72.7",	-- Webwinder Hollow
		"66.9;66.2",	-- Krom'gar Fortress
	},
	[Zone.Ashenvale] = {
		"53.2;32.6",	-- The Howling Vale
		"35.9;50.2",	-- Astranaar
		"68.2;47.9",	-- Splintertree Post
		"21.4;55.3",	-- The Shrine of Aessina
		"32.6;65.6",	-- The Ruins of Stardust
		"80.4;49.7",	-- Satyrnaar
		"93.4;39.2",	-- Bough Shadow
		"37.0;32.9",	-- Thistlefur Village
		"14.0;23.0",	-- The Zoram Strand
		"20.2;41.1",	-- Lake Falathim
		"66.0;82.0",	-- Fallen Sky Lake
		"27.5;37.7",	-- Maestra's Post
		"59.7;50.0",	-- Raynewood Retreat
		"83.1;65.3",	-- Felfire Hill
		"26.0;19.7",	-- Orendil's Retreat
		"50.15;67.08",	-- Silverwind Refuge
		"48.9;46.4",	-- Thunder Peak
		"87.4;58.6",	-- Warsong Lumber Camp
	},
	[Zone.MountHyjal] = {
		"45.1;26.0",	-- The Circle of Cinders
		"31.8;53.5",	-- Ashen Lake
		"45.3;80.5",	-- The Throne of Flame
		"25.5;64.5",	-- Rim of the World
		"76.0;64.9",	-- Darkwhisper Gorge
		"72.5;76.7",	-- Gates of Sothann
		"63.4;21.0",	-- Nordrassil
		"31.4;84.9",	-- Sethria's Roost
		"28.5;27.5",	-- Shrine of Goldrinn
		"53.4;55.1",	-- The Scorched Plain
		"32.9;51.2",	-- The Flamewake
	},
	[Zone.Winterspring] = {
		"47.7;39.1",	-- Starfall Village
		"51.1;55.1",	-- Lake Kel'Theril
		"67.8;64.4",	-- Ice Thistle Hills
		"31.9;49.3",	-- Frostfire Hot Springs
		"36.4;56.7",	-- Timbermaw Post
		"59.8;85.5",	-- Frostwhisper Gorge
		"68.1;48.5",	-- Winterfall Village
		"64.5;77.2",	-- Owl Wing Thicket
		"59.9;48.9",	-- Everlook
		"54.8;62.9",	-- Mazthoril
		"62.7;24.7",	-- The Hidden Grove
		"45.3;15.4",	-- Frostsaber Rock
	},
	[Zone.Azshara] = {
		"46.54;76.25",	-- The Secret Lab
		"25.47;38.00",	-- Bear's Head
		"33.06;32.76",	-- Blackmaw Hold
		"64.65;79.31",	-- Ravencrest Monument
		"56.99;76.50",	-- Storm Cliffs
		"21.04;57.1",	-- Gallywix Pleasure Palace
		"39.83;84.67",	-- The Ruined Reaches
		"58.29;51.00",	-- Bilgewater Harbor
		"52.25;26.95",	-- Darnassian Base Camp
		"39.21;55.46",	-- The Shattered Strand
		"80.90;32.34",	-- Tower of Eldara
		"69.89;34.83",	-- Ruins of Arkkoran
		"26.75;77.96",	-- Orgrimmar Rear Gate
		"31.95;50.02",	-- Ruins of Eldarath
		"35.72;73.99",	-- Lake Mennar
		"68.41;75.62",	-- Southridge Beach
		"73.69;20.98",	-- Bitter Reaches
	},
	[Zone.Moonglade] = {
		"52.5;55.4",	-- Lake Elune'ara
		"36.3;38.8",	-- Shrine of Remulos
		"48.2;37.9",	-- Nighthaven
		"67.8;53.8",	-- Stormrage Barrow Dens
	},
	[Zone.Felwood] = {
		"41.0;47.0",	-- Bloodvenom Falls
		"43.6;18.6",	-- Jadefire Run
		"37.0;59.1",	-- Jaedenar
		"52.2;78.2",	-- Emerald Sanctuary
		"48.0;89.2",	-- Deadwood Village
		"56.6;86.8",	-- Morlos'Aran
		"50.3;26.0",	-- Irontree Woods
		"38.0;72.3",	-- Ruins of Constellas
		"43.1;41.9",	-- Shatter Scar Vale
		"41.8;85.4",	-- Jadefire Glen
		"61.2;11.5",	-- Felpaw Village
		"62.6;26.7",	-- Talonbranch Glade
	},
	[Zone.Darkshore] = {
		"63.9;21.9",	-- Ruins of Mathystra
		"32.0;84.0",	-- Nazj'vel
		"37.9;44.1",	-- Ruins of Auberdine
		"43.7;60.5",	-- Ameth'Aran
		"40.3;86.2",	-- The Master's Glaive
		"42.9;54.9",	-- The Eye of the Vortex
		"51.2;19.2",	-- Lor'danel
		"72.5;17.3",	-- Shatterspear Vale
		"65.9;7.0",		-- Shatterspear War Camp
		"43.96;39.82",	-- Withering Thicket
		"42.5;69.5",	-- Wildbend River
	},
	[Zone.Teldrassil] = {
		"64.7;49.1",	-- Starbreeze Village
		"40.0;26.7",	-- The Oracle Glade
		"44.4;34.4",	-- Wellspring Lake
		"30.4;50.1",	-- Darnassus
		"55.0;61.0",	-- Lake Al'Ameth
		"58.4;33.0",	-- Shadowglen
		"46.16;50.68",	-- Ban'ethil Hollow
		"44.8;67.4",	-- Gnarlpine Hold
		"55.0;91.0",	-- Rut'theran Village
		"41.9;56.9",	-- Pools of Arlithrien
		"50.7;38.0",	-- The Cleft
		"55.6;51.2",	-- Dolanaar
	},
	[Zone.AzuremystIsle] = {
		"77.6;43.7",	-- Ammen Vale
		"61.3;53.6",	-- Ammen Ford
		"52.7;41.8",	-- Moongraze Woods
		"52.7;61.3",	-- Pod Wreckage
		"46.0;20.0",	-- Stillpine Hold
		"29.2;35.1",	-- The Exodar
		"58.8;17.6",	-- Emberglade
		"35.3;12.4",	-- Silting Shore
		"46.6;72.4",	-- Odesyus' Landing
		"23.7;54.0",	-- Valaar's Berth
		"49.3;50.7",	-- Azure Watch
		"58.3;67.0",	-- Geezle's Camp
		"32.0;79.3",	-- Wrathscale Point
		"26.5;65.1",	-- Bristlelimb Village
		"37.0;58.4",	-- Pod Cluster
		"12.7;78.6",	-- Silvermyst Isle
		"47.7;6.6",		-- Fairbridge Strand
	},
	[Zone.BloodmystIsle] = {
		"32.7;19.8",	-- The Hidden Reef
		"30.2;46.2",	-- Vindicator's Rest
		"69.0;66.6",	-- Wrathscale Lair
		"38.5;59.5",	-- The Cryo-Core
		"40.8;33.0",	-- Axxarien
		"45.9;45.1",	-- Bladewood
		"85.4;52.8",	-- Bloodcurse Isle
		"18.8;30.9",	-- Amberweb Pass
		"54.6;55.4",	-- Blood Watch
		"67.0;78.2",	-- Bristlelimb Enclave
		"61.9;90.0",	-- Kessel's Crossing
		"43.9;84.7",	-- Mystwood
		"72.0;29.6",	-- Wyrmscar Island
		"57.4;81.0",	-- The Lost Fold
		"61.6;45.2",	-- Ruins of Loreth'Aran
		"38.7;21.9",	-- The Bloodwash
		"37.9;75.7",	-- Nazzivian
		"73.4;20.9",	-- Talon Stand
		"62.6;25.4",	-- The Crimson Reach
		"18.0;53.4",	-- The Vector Coil
		"29.2;36.8",	-- The Foul Pool
		"74.4;7.5",		-- Veridian Point
		"33.2;90.3",	-- Blacksilt Shore
		"24.4;41.2",	-- Tel'athion's Camp
		"54.2;17.1",	-- The Warp Piston
		"51.7;76.6",	-- Middenvale
		"81.0;20.1",	-- The Bloodcursed Reef
		"56.1;34.9",	-- Ragefeather Ridge
	},
	[Zone.Azsuna] = {
		"65.8;27.9",	-- Felblaze Ingress
		"57.1;64.8",	-- Temple of Lights
		"55.7;41.4",	-- NMar'thalas
		"41.4;39.0",	-- Llothien Highlands
		"60.6;34.9",	-- The Greenway
		"46.8;73.1",	-- Isle of the Watchers
		"65.6;49.0",	-- Ruined Sanctum
		"52.7;16.8",	-- Ley-ruins of Zarkhenar
		"39.6;50.2",	-- Faronaar
		"48.0;13.6",	-- Lost Orchard
		"53.8;58.9",	-- Oceanus Cove
	},
	[Zone.Highmountain] = {
		"43.7;8.7",		-- Shipwreck Cove
		"56.9;90.0",	-- Highmountain Summit
		"35.6;63.6",	-- Sylvan Falls
		"52.6;44.8",	-- Skyhorn
		"58.7;64.7",	-- Stonehoof Watch
		"55.6;83.9",	-- Ironhorn Enclave
		"56.4;21.8",	-- Rockaway Shallows
		"46.2;61.4",	-- Thunder Totem
		"38.9;67.8",	-- Riverbend
		"43.0;33.5",	-- Bloodhunt Highlands
		"29.3;33.4",	-- Blind Marshlands
		"27.3;54.6",	-- Nightwatcher's Perch
		"32.5;45.7",	-- Trueshot Lodge
		"43.1;51.7",	-- Pinerock Basin
	},
	[Zone.Suramar] = {
		"38.1;22.9",	-- Moon Guard Stronghold
		"42.2;35.5",	-- Tel'anor
		"90.9;62.6",	-- Ruins of Elun'eth
		"19.5;45.2",	-- Falanaar
		"47.3;50.4",	-- The Grand Pomenade
		"34.9;31.0",	-- Moonwhisper Gulch
		"46.1;39.8",	-- Suramar City
		"64.0;42.0",	-- Crimson Thicket
		"34.3;74.8",	-- Felsoul Hold
		"71.5;51.1",	-- Jandvik
		"30.4;42.3",	-- Ambervale
	},
	[Zone.Valsharah] = {
		"67.6;56.4",	-- Andutalah
		"25.5;66.5",	-- Gloaming Reef
		"47.9;69.6",	-- Thas'talah
		"71.6;39.1",	-- Mistvale
		"51.2;73.1",	-- Moonclaw Vale
		"42.4;58.6",	-- Bradensbrook
		"54.6;73.0",	-- Lorlathil
		"51.9;64.0",	-- Grove of Cenarius
		"51.1;31.1",	-- Shala'nir
		"47.3;85.1",	-- Smolderhide Thicket
		"38.8;51.8",	-- Black Rook Hold
		"44.2;30.4",	-- The Dreamgrove
		"54.1;55.4",	-- Temple of Elune
	},
	[Zone.Stormheim] = {
		"72.0;60.0",	-- Greywatch
		"55.6;73.6",	-- Dreadwake's Landing
		"75.2;54.8",	-- Dreyrgrot
		"73.4;39.7",	-- Haustvald
		"65.7;62.6",	-- Skold-Ashil
		"33.9;34.7",	-- Blackbeak Overlook
		"65.6;62.2",	-- Gates of Valor
		"44.3;64.5",	-- Hrydshal
		"47.6;44.8",	-- Aggrammar's Vault
		"80.1;59.2",	-- Morheim
		"69.9;22.0",	-- Watchman's Rock
		"77.8;6.7",		-- Shield's Rest
		"71.5;50.1",	-- The Runewood
		"44.9;37.0",	-- Nastrondir
		"38.8;20.4",	-- Maw of Nashal
		"59.1;31.2",	-- Storm's Reach
		"51.4;37.0",	-- Talonrest
		"58.0;44.4",	-- Tideskorn Harbor
		"60.4;51.1",	-- Valdisdall
		"34.5,51.3",	-- Weeping Bluffs
	}
}

local exploreContinent = {
	[Continent.Kalimdor] = {
		exploreCoords[Zone.Durotar],
		exploreCoords[Zone.Mulgore],
		exploreCoords[Zone.NorthernBarrens],
		exploreCoords[Zone.Teldrassil],
		exploreCoords[Zone.darkshore],
		exploreCoords[Zone.Ashenvale],
		exploreCoords[Zone.ThousandNeedles],
		exploreCoords[Zone.StonetalonMountains],
		exploreCoords[Zone.Desolace],
		exploreCoords[Zone.Feralas],
		exploreCoords[Zone.DustwallowMarsh],
		exploreCoords[Zone.Tannaris],
		exploreCoords[Zone.Azshara],
		exploreCoords[Zone.Felwood],
		exploreCoords[Zone.UnGoroCrater],
		exploreCoords[Zone.Moonglade],
		exploreCoords[Zone.Silithus],
		exploreCoords[Zone.Winterspring],
		exploreCoords[Zone.AzuremystIsle],
		exploreCoords[Zone.BloodmystIsle],
		exploreCoords[Zone.SouthernBarrens],
	},
	[Continent.EasternKingdoms] = {
		exploreCoords[Zone.DunMorogh],
		exploreCoords[Zone.ArathiHighlands],
		exploreCoords[Zone.Badlands],
		exploreCoords[Zone.BlastedLands],
		exploreCoords[Zone.TirisfalGlades],
		exploreCoords[Zone.SilverpineForest],
		exploreCoords[Zone.WesternPlaguelands],
		exploreCoords[Zone.EasternPlaguelands],
		exploreCoords[Zone.HillsbradFoothills],
		exploreCoords[Zone.Hinterlands],
		exploreCoords[Zone.SearingGorge],
		exploreCoords[Zone.BurningSteppes],
		exploreCoords[Zone.ElwynnForest],
		exploreCoords[Zone.DeadwindPass],
		exploreCoords[Zone.Duskwood],
		exploreCoords[Zone.LochModan],
		exploreCoords[Zone.RedridgeMountains],
		exploreCoords[Zone.NorthernStranglethron],
		exploreCoords[Zone.SwampOfSorrows],
		exploreCoords[Zone.Westfall],
		exploreCoords[Zone.Wetlands],
		exploreCoords[Zone.Ghostlands],
		exploreCoords[Zone.EversongWoods],
		exploreCoords[Zone.IsleOfQuelDanas],
		exploreCoords[Zone.CapeOfStranglethron],
	},
	[Continent.Outland] = {
		exploreCoords[Zone.Netherstorm],
		exploreCoords[Zone.HellfirePeninsula],
		exploreCoords[Zone.Zangarmarsh],
		exploreCoords[Zone.ShadowmoonValleyOutland],
		exploreCoords[Zone.BladesEdgeMountains],
		exploreCoords[Zone.NagrandOutland],
		exploreCoords[Zone.TerokkarForest],
	},
	[Continent.Northrend] = {
		exploreCoords[Zone.CrystalsongForest],
		exploreCoords[Zone.HowlingFjord],
		exploreCoords[Zone.BoreanTundra],
		exploreCoords[Zone.Dragonblight],
		exploreCoords[Zone.GrizzlyHills],
		exploreCoords[Zone.ZulDrak],
		exploreCoords[Zone.SholazarBasin],
		exploreCoords[Zone.StormPeaks],
		exploreCoords[Zone.Icecrown],
	},
	[Continent.Cataclysm] = {
		exploreCoords[Zone.Vashjir],
		exploreCoords[Zone.MountHyjal],
		exploreCoords[Zone.Deepholm],
		exploreCoords[Zone.Uldum],
		exploreCoords[Zone.TwilightHighlands],
	},
	[Continent.Pandaria] = {
		exploreCoords[Zone.JadedForest],
		exploreCoords[Zone.ValleyOfTheFourWinds],
		exploreCoords[Zone.KunLaiSummit],
		exploreCoords[Zone.TownlongSteppes],
		exploreCoords[Zone.ValeOfEternalBlossoms],
		exploreCoords[Zone.KrasarangWilds],
		exploreCoords[Zone.DreadWastes],
	},
	[Continent.Draenor] = {
		exploreCoords[Zone.ForstfireRidge],
		exploreCoords[Zone.ShadowmoonValleyDraenor],
		exploreCoords[Zone.Gorgrond],
		exploreCoords[Zone.Talador],
		exploreCoords[Zone.SpiresOfArak],
		exploreCoords[Zone.NagrandDraenor],
	},
	[Continent.BrokenIsles] = {
		exploreCoords[Zone.Azsuna],
		exploreCoords[Zone.Valsharah],
		exploreCoords[Zone.Highmountain],
		exploreCoords[Zone.Stormheim],
		exploreCoords[Zone.Suramar],
	}
}

local pairs, select = pairs, select

for zoneID, achievementID in pairs(exploreAchievements) do
	private:debug("Registering guide for: " .. achievementID)
	local _, achievementName, _, achievementCompleted = GetAchievementInfo(achievementID)
	if not achievementCompleted then
		local coords = exploreCoords[zoneID]
		if not coords then
			coords = exploreContinent[zoneID]
		end
		private:RegisterGuide({
			achieveID = achievementID,
			coords = coords,
			exec = function()
				local nearestCoordsIndex, nearestCoordsDistance = -1, math.huge
				local destX, destY, distance
				for coordsIndex, coord in pairs(coords) do
					if not select(3, GetAchievementCriteriaInfo(achievementID, coordsIndex)) then
						destX, destY = (";"):split(coord)
						distance = private:GetDistance(zoneID, destX, destY)
						if not distance then
							print("Please go to the correct continent to load this guide.")
							return
						end
						if distance < nearestCoordsDistance then
							private:debug("Closer co-ords found: " .. distance .. " (" .. nearestCoordsDistance .. ")")
							nearestCoordsIndex = coordsIndex
							nearestCoordsDistance = distance
						end
					end
				end
				if nearestCoordsIndex ~= -1 then
					local zoneName = GetAchievementCriteriaInfo(achievementID, nearestCoordsIndex)
					local nearestCoords = coords[nearestCoordsIndex]
					private:SetGuideText(achievementName .. "\nVisit " .. zoneName .. "\nGo to: " .. nearestCoords)
					local x, y = (";"):split(nearestCoords)
					private:AddWaypoint(zoneID, x, y, "Visit " .. zoneName)
				else
					private:RemoveWaypoint()
				end
				return nearestCoordsIndex
			end
		})
	else
		private:debug("We've already completed " .. achievementID .. " - Skipping.")
	end
end